.. LexicalRichness documentation master file, created by
   sphinx-quickstart on Tue Aug 16 21:35:10 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
    :caption: Readme:
    :maxdepth: 1

    README

.. toctree::
    :caption: Appendix:
    :maxdepth: 1

    example.ipynb
    details
    docstring_docs  
    
=============================
LexicalRichness Documentation
=============================

.. include:: usefullinks.rst
.. include:: README.rst
.. include:: contributors.rst
.. include:: details.rst
.. include:: docstring_docs.rst
